BasicCancelToken class

Concrete CancelToken backed by Dio's cancel token.

Implemented types

Constructors

BasicCancelToken()
Creates a cancel token.

Properties

cancelReason String?
Reason provided to cancel, if any.
no setteroverride
dioToken → CancelToken
Underlying Dio cancel token used by DioRestHttpEngine.
no setter
hashCode int
The hash code for this object.
no setterinherited
isCancelled bool
Whether cancellation has been requested.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
whenCancelled Future<void>
Completes when cancel is called.
no setteroverride

Methods

cancel([String? reason]) → void
Requests cancellation of the associated call.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited