BasicMultipartPart class

Concrete multipart part.

Implemented types

Constructors

BasicMultipartPart({required String name, required Object value, String? fileName, String? contentType})
Creates a multipart part.
const

Properties

contentType String?
Optional MIME type.
final
fileName String?
Optional file name for file parts.
final
hashCode int
The hash code for this object.
no setterinherited
name String
Form field name.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value Object
Opaque part payload (bytes, string, or adapter-specific handle).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited